@@ -5,15 +5,15 @@ from modules.TOMLSerializerCreator import TomlSerializerCreator
 from modules.YAMLSerializerCreator import YamlSerializerCreator
 
 parser = argparse.ArgumentParser(description='Process converting between formats.')
-parser.add_argument('source', type=str,
+parser.add_argument('-source', dest='-source', type=str,
                     help='source file path')
-parser.add_argument('source_format', type=str,
+parser.add_argument('-source_format', dest='-source_format', type=str,
                     help='source format')
-parser.add_argument('destination', type=str,
+parser.add_argument('-destination', dest='-destination', type=str,
                     help='destination file path')
-parser.add_argument('format', type=str,
+parser.add_argument('-format', dest='-format', type=str,
                     help='new format')
-parser.add_argument('conf_file', type=str,
+parser.add_argument('-conf_file', dest="conf_file", type=str,
                     help='configuration file')
 
 formats = {'JSON': JsonSerializerCreator(), 'YAML': YamlSerializerCreator(), 'TOML': TomlSerializerCreator()}
@@ -26,7 +26,7 @@ def setup():
     destination = None
     format = None
     if args.conf_file is not None and args.conf_file is "config.py":
-        config =__import__(config_file_name)
+        config = __import__(args.conf_file)
         flag = False
 
         if hasattr(config, "source"):
